<p align="center">
  <img src="https://raw.githubusercontent.com/pyload/pyload/main/media/logo.png" alt="pyLoad" height="100" />
</p>

## Security Policy

### Supported Versions

pyLoad Next releases will receive security vulnerabilities patches.
Old versions of pyLoad, working on Python 2, will receive plugin updates only.

### Reporting a Vulnerability

Please report any security vulnerabilities by sending an email to security@pyload.net.

You will receive a response from us within a short time.
If the issue is confirmed, we will release a patch as soon as possible depending on complexity.

<br />

---

###### © 2008-2023 pyLoad team
